@@ -1,6 +1,6 @@
 """Python SDK for the AICostManager API."""
 
-__version__ = "0.1.23"
+__version__ = "0.1.33"
 
 from .client import (
     AICMError,
@@ -30,6 +30,7 @@ from .wrappers import (
     GeminiWrapper,
     BedrockWrapper,
 )
+from .costs import CostQueryManager
 
 __all__ = [
     "AICMError",
@@ -56,5 +57,6 @@ __all__ = [
     "AnthropicWrapper",
     "GeminiWrapper",
     "BedrockWrapper",
+    "CostQueryManager",
     "__version__",
 ]
