@@ -9,9 +9,6 @@ from .common import (
     ValidationError,
 )
 from .usage import (
-    ApiUsageRecord,
-    ApiUsageRequest,
-    ApiUsageResponse,
     RollupFilters,
     UsageEvent,
     UsageEventFilters,
@@ -20,6 +17,7 @@ from .usage import (
 from .customers import CustomerFilters, CustomerIn, CustomerOut
 from .limits import UsageLimitIn, UsageLimitOut, UsageLimitProgressOut
 from .services import CostUnitOut, ServiceOut, VendorOut
+from .costs import CostEvent, CostEventFilters, CostEventsResponse
 from .config import ServiceConfigItem, ServiceConfigListResponse
 
 __all__ = [
@@ -29,9 +27,6 @@ __all__ = [
     "Period",
     "ThresholdType",
     "ValidationError",
-    "ApiUsageRecord",
-    "ApiUsageRequest",
-    "ApiUsageResponse",
     "RollupFilters",
     "UsageEvent",
     "UsageEventFilters",
@@ -45,6 +40,9 @@ __all__ = [
     "CostUnitOut",
     "ServiceOut",
     "VendorOut",
+    "CostEvent",
+    "CostEventFilters",
+    "CostEventsResponse",
     "ServiceConfigItem",
     "ServiceConfigListResponse",
 ]
